# NEETBOX

![](./docs/static/img/readme.png)

A tool box for Logging/Debugging/Tracing/Managing/Facilitating long running python projects, especially a replacement of tensorboard for deep learning projects.

[![wakatime](https://wakatime.com/badge/user/b93a26b6-8ea1-44ef-99ed-bcb6e2c732f1/project/8f99904d-dbb1-49e4-814d-8d18bf1e6d1c.svg)](https://wakatime.com/badge/user/b93a26b6-8ea1-44ef-99ed-bcb6e2c732f1/project/8f99904d-dbb1-49e4-814d-8d18bf1e6d1c) [![pytest](https://github.com/visualDust/neetbox/actions/workflows/poetry-pytest.yml/badge.svg)](https://github.com/visualDust/neetbox/actions/workflows/poetry-pytest.yml) ![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/visualdust/neetbox/build-and-publish-pypi.yml) ![PyPI - Version](https://img.shields.io/pypi/v/neetbox)
![PyPI - Downloads](https://img.shields.io/pypi/dw/neetbox) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![codecov](https://codecov.io/gh/visualDust/neetbox/graph/badge.svg?token=WYWLQ4YKZJ)](https://codecov.io/gh/visualDust/neetbox)

supported platforms:

![linux](https://img.shields.io/badge/linux-x86%20or%20arm-blue?logo=linux) ![windows](https://img.shields.io/badge/windows-x86%20or%20arm-blue?logo=windows) ![mac os](https://img.shields.io/badge/mac-intel%20or%20apple%20silicon-blue?logo=apple)

## Screenshots


![image](https://github.com/visualDust/neetbox/assets/33346934/593df42b-13d4-4239-92ab-a7ca452c904a)
![image](https://github.com/visualDust/neetbox/assets/33346934/47df39c9-cda2-4dba-a9a2-7ef866c5c8ab)
![image](https://github.com/visualDust/neetbox/assets/33346934/acdbfd22-dd3b-4b7c-a446-2022125ba5c9)

## How to use

See the project website: [neetbox.550w.host](https://neetbox.550w.host)


## Dev plans

NEETBOX is under heavy development.

- [x] monit multi project on one dashboard
- [x] local/remote logging
- [x] command line cli tools
- [x] system monitoring
- [x] post images/tensor as images to frontend
- [x] plotting(scatters, line chart...)
- [x] run python code by clicking on frontend buttons
- [x] history automatically saved by backend
- [x] distinguish different runs
- [ ] compare data from different runs

## Contributors

<a href = "https://github.com/visualDust/neetbox/graphs/contributors">
  <img src = "https://contrib.rocks/image?repo=VisualDust/neetbox"/>
</a>

## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=visualDust/neetbox&type=Date)](https://star-history.com/#visualDust/neetbox&Date)
